==> directfb_0.9.20.orig.tar.gz: DirectFB-0.9.20/src/core/clipboard.h <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   (c) Copyright 2002       convergence GmbH.
   
   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de> and
              Sven Neumann <sven@convergence.de>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __CORE__CLIPBOARD_H__
#define __CORE__CLIPBOARD_H__

#include <directfb.h>

DFBResult dfb_clipboard_set( const char     *mime_type,
                             const void     *data,
                             unsigned int    size,
                             struct timeval *timestamp );

DFBResult dfb_clipboard_get( char         **mime_type,
                             void         **data,
                             unsigned int  *size );

DFBResult dfb_clipboard_get_timestamp( struct timeval *timestamp );

#endif

==> directfb_0.9.22.orig.tar.gz: DirectFB-0.9.22/src/core/clipboard.h <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   (c) Copyright 2002-2004  convergence GmbH.

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de>,
              Sven Neumann <neo@directfb.org> and
              Ville Syrjl <syrjala@sci.fi>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __CORE__CLIPBOARD_H__
#define __CORE__CLIPBOARD_H__

#include <directfb.h>

DFBResult dfb_clipboard_set( const char     *mime_type,
                             const void     *data,
                             unsigned int    size,
                             struct timeval *timestamp );

DFBResult dfb_clipboard_get( char         **mime_type,
                             void         **data,
                             unsigned int  *size );

DFBResult dfb_clipboard_get_timestamp( struct timeval *timestamp );

#endif
